"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.excludeMethod = exports.Bindings = void 0;
const common_1 = require("@nestjs/common");
const mixin_1 = require("../mixin");
const pipes_1 = require("../mixin/pipes");
const constants_1 = require("../constants");
const Bindings = {
    getAll: {
        method: common_1.RequestMethod.GET,
        name: 'getAll',
        path: '',
        implementation: mixin_1.JsonBaseController.prototype['getAll'],
        parameters: [
            {
                decorator: common_1.Query,
                mixins: [
                    pipes_1.querySchemaMixin,
                    pipes_1.queryTransformMixin,
                    pipes_1.queryTransformSchemaMixin,
                    pipes_1.queryFiledInIncludeMixin,
                ],
            },
        ],
    },
    getOne: {
        method: common_1.RequestMethod.GET,
        name: 'getOne',
        path: `:${constants_1.PARAMS_RESOURCE_ID}`,
        implementation: mixin_1.JsonBaseController.prototype['getOne'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
            {
                decorator: common_1.Query,
                mixins: [
                    pipes_1.querySchemaMixin,
                    pipes_1.queryTransformMixin,
                    pipes_1.queryTransformSchemaMixin,
                    pipes_1.queryFiledInIncludeMixin,
                ],
            },
        ],
    },
    deleteOne: {
        method: common_1.RequestMethod.DELETE,
        name: 'deleteOne',
        path: `:${constants_1.PARAMS_RESOURCE_ID}`,
        implementation: mixin_1.JsonBaseController.prototype['deleteOne'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
        ],
    },
    postOne: {
        method: common_1.RequestMethod.POST,
        name: 'postOne',
        path: '',
        implementation: mixin_1.JsonBaseController.prototype['postOne'],
        parameters: [
            {
                decorator: common_1.Body,
                mixins: [pipes_1.bodyInputPostMixin],
            },
        ],
    },
    patchOne: {
        method: common_1.RequestMethod.PATCH,
        name: 'patchOne',
        path: `:${constants_1.PARAMS_RESOURCE_ID}`,
        implementation: mixin_1.JsonBaseController.prototype['patchOne'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
            {
                decorator: common_1.Body,
                mixins: [pipes_1.bodyInputPatchPipeMixin],
            },
        ],
    },
    getRelationship: {
        path: `:${constants_1.PARAMS_RESOURCE_ID}/relationships/:${constants_1.PARAMS_RELATION_NAME}`,
        name: 'getRelationship',
        method: common_1.RequestMethod.GET,
        implementation: mixin_1.JsonBaseController.prototype['getRelationship'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
            {
                property: constants_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [pipes_1.parseRelationshipNameMixin],
            },
        ],
    },
    deleteRelationship: {
        path: `:${constants_1.PARAMS_RESOURCE_ID}/relationships/:${constants_1.PARAMS_RELATION_NAME}`,
        name: 'deleteRelationship',
        method: common_1.RequestMethod.DELETE,
        implementation: mixin_1.JsonBaseController.prototype['deleteRelationship'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
            {
                property: constants_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [pipes_1.parseRelationshipNameMixin],
            },
            {
                decorator: common_1.Body,
                mixins: [pipes_1.bodyRelationshipPipeMixin],
            },
        ],
    },
    postRelationship: {
        path: `:${constants_1.PARAMS_RESOURCE_ID}/relationships/:${constants_1.PARAMS_RELATION_NAME}`,
        name: 'postRelationship',
        method: common_1.RequestMethod.POST,
        implementation: mixin_1.JsonBaseController.prototype['postRelationship'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
            {
                property: constants_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [pipes_1.parseRelationshipNameMixin],
            },
            {
                decorator: common_1.Body,
                mixins: [pipes_1.bodyRelationshipPipeMixin],
            },
        ],
    },
    patchRelationship: {
        path: `:${constants_1.PARAMS_RESOURCE_ID}/relationships/:${constants_1.PARAMS_RELATION_NAME}`,
        name: 'patchRelationship',
        method: common_1.RequestMethod.PATCH,
        implementation: mixin_1.JsonBaseController.prototype['patchRelationship'],
        parameters: [
            {
                property: constants_1.PARAMS_RESOURCE_ID,
                decorator: common_1.Param,
                mixins: [pipes_1.idPipeMixin],
            },
            {
                property: constants_1.PARAMS_RELATION_NAME,
                decorator: common_1.Param,
                mixins: [pipes_1.parseRelationshipNameMixin],
            },
            {
                decorator: common_1.Body,
                mixins: [pipes_1.bodyRelationshipPatchPipeMixin],
            },
        ],
    },
};
exports.Bindings = Bindings;
function excludeMethod(names) {
    const tmpObject = names.reduce((acum, key) => ((acum[key] = true), acum), {});
    return Object.keys(Bindings).filter((method) => !tmpObject[method]);
}
exports.excludeMethod = excludeMethod;
//# sourceMappingURL=bindings.js.map